==> ckeditor_4.9.2+dfsg.orig.tar.xz: ckeditor-dev-4.9.2/plugins/docprops/lang/bg.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'bg', {
	bgColor: 'Фон',
	bgFixed: 'Non-scrolling (Fixed) Background', // MISSING
	bgImage: 'Background Image URL', // MISSING
	charset: 'Кодова таблица',
	charsetASCII: 'ASCII',
	charsetCE: 'Централна европейска',
	charsetCR: 'Cyrillic', // MISSING
	charsetCT: 'Китайски традиционен',
	charsetGR: 'Greek', // MISSING
	charsetJP: 'Japanese', // MISSING
	charsetKR: 'Korean', // MISSING
	charsetOther: 'Друга кодова таблица',
	charsetTR: 'Turkish', // MISSING
	charsetUN: 'Unicode (UTF-8)', // MISSING
	charsetWE: 'Western European', // MISSING
	chooseColor: 'Изберете',
	design: 'Дизайн',
	docTitle: 'Заглавие на страницата',
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Other Document Type Heading', // MISSING
	label: 'Настройки на документа',
	margin: 'Page Margins', // MISSING
	marginBottom: 'Долу',
	marginLeft: 'Ляво',
	marginRight: 'Дясно',
	marginTop: 'Горе',
	meta: 'Мета етикети',
	metaAuthor: 'Author', // MISSING
	metaCopyright: 'Copyright', // MISSING
	metaDescription: 'Document Description', // MISSING
	metaKeywords: 'Document Indexing Keywords (comma separated)', // MISSING
	other: 'Други...',
	previewHtml: '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>', // MISSING
	title: 'Настройки на документа',
	txtColor: 'Цвят на шрифт',
	xhtmlDec: 'Include XHTML Declarations' // MISSING
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/docprops/lang/bg.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'bg', {
	bgColor: 'Фон',
	bgFixed: 'Без превъртане (фиксиран) фон',
	bgImage: 'URL на изображение за фон',
	charset: 'Кодова таблица',
	charsetASCII: 'ASCII',
	charsetCE: 'Централна европейска',
	charsetCR: 'Cyrillic', // MISSING
	charsetCT: 'Китайски традиционен',
	charsetGR: 'Greek', // MISSING
	charsetJP: 'Japanese', // MISSING
	charsetKR: 'Korean', // MISSING
	charsetOther: 'Друга кодова таблица',
	charsetTR: 'Turkish', // MISSING
	charsetUN: 'Unicode (UTF-8)', // MISSING
	charsetWE: 'Western European',
	chooseColor: 'Изберете',
	design: 'Дизайн',
	docTitle: 'Заглавие на страницата',
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Other Document Type Heading', // MISSING
	label: 'Настройки на документа',
	margin: 'Page Margins', // MISSING
	marginBottom: 'Долу',
	marginLeft: 'Ляво',
	marginRight: 'Дясно',
	marginTop: 'Горе',
	meta: 'Мета етикети',
	metaAuthor: 'Author', // MISSING
	metaCopyright: 'Copyright', // MISSING
	metaDescription: 'Document Description', // MISSING
	metaKeywords: 'Document Indexing Keywords (comma separated)', // MISSING
	other: 'Други...',
	previewHtml: '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>', // MISSING
	title: 'Настройки на документа',
	txtColor: 'Цвят на шрифт',
	xhtmlDec: 'Include XHTML Declarations' // MISSING
} );
